loadtestutil

package
v2.31.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: AGPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

const (
	// Prefix for all scaletest resources (users and workspaces)
	ScaleTestPrefix = "scaletest"

	// Email domain for scaletest users
	EmailDomain = "@scaletest.local"

	DefaultRandLength = 8
)

Variables

This section is empty.

Functions

func CreateTarFromFiles added in v2.29.0

func CreateTarFromFiles(files map[string][]byte) ([]byte, error)

func DupClientCopyingHeaders added in v2.30.0

func DupClientCopyingHeaders(client *codersdk.Client, header http.Header) (*codersdk.Client, error)

DupClientCopyingHeaders duplicates the Client, but with an independent underlying HTTP transport, so that it will not share connections with the client being duplicated. It copies any headers already on the existing transport as codersdk.HeaderTransport and add the headers in the argument.

func GenerateUserIdentifier added in v2.27.0

func GenerateUserIdentifier(id string) (username, email string, err error)

GenerateUserIdentifier generates a username and email for scale testing. The username follows the pattern: scaletest-<random>-<id> The email follows the pattern: <random>-<id>@scaletest.local

func GenerateWorkspaceName added in v2.27.0

func GenerateWorkspaceName(id string) (name string, err error)

GenerateWorkspaceName generates a workspace name for scale testing. The workspace name follows the pattern: scaletest-<random>-<id>

func IsScaleTestUser added in v2.27.0

func IsScaleTestUser(username, email string) bool

IsScaleTestUser checks if a username indicates it was created for scale testing.

func IsScaleTestWorkspace added in v2.27.0

func IsScaleTestWorkspace(workspaceName, ownerName string) bool

IsScaleTestWorkspace checks if a workspace name indicates it was created for scale testing.

Types

type SyncWriter

type SyncWriter struct {
	// contains filtered or unexported fields
}

SyncWriter wraps an io.Writer in a sync.Mutex.

func NewSyncWriter

func NewSyncWriter(w io.Writer) *SyncWriter

func (*SyncWriter) Close

func (sw *SyncWriter) Close() error

func (*SyncWriter) Write

func (sw *SyncWriter) Write(p []byte) (n int, err error)

Write implements io.Writer.

Jump to