Documentation
¶
Index ¶
Constants ¶
const (
WorkspaceUpdatesLatencyMetric = "workspace_updates_latency_seconds"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// User is the configuration for the user to create.
User createusers.Config `json:"user"`
// Workspace is the configuration for the workspace to create. The workspace
// will be built using the new user.
//
// OrganizationID is ignored and set to the new user's organization ID.
Workspace workspacebuild.Config `json:"workspace"`
// WorkspaceCount is the number of workspaces to create.
WorkspaceCount int64 `json:"power_user_workspaces"`
// WorkspaceUpdatesTimeout is how long to wait for all expected workspace updates.
WorkspaceUpdatesTimeout time.Duration `json:"workspace_updates_timeout"`
// DialTimeout is how long to wait to successfully dial the Coder Connect
// endpoint.
DialTimeout time.Duration `json:"dial_timeout"`
Metrics *Metrics `json:"-"`
// DialBarrier is used to ensure all runners have dialed the Coder Connect
// endpoint before creating their workspace(s).
DialBarrier *sync.WaitGroup `json:"-"`
}
type Metrics ¶
type Metrics struct {
WorkspaceUpdatesLatencySeconds prometheus.HistogramVec
WorkspaceUpdatesErrorsTotal prometheus.CounterVec
}
func NewMetrics ¶
func NewMetrics(reg prometheus.Registerer) *Metrics
Click to show internal directories.
Click to hide internal directories.